@@ -23,6 +23,11 @@ requests.packages.urllib3.disable_warnings()
 # verbose is enabled/disabled via property file.  See main() below.
 verbose=False
 
+def _prefixProperty(property, prefix):
+    if property.startswith(prefix):
+        return property
+    return "%s%s" % (prefix, property)
+
 class CipresError(Exception):
     def __init__(self, httpStatus, cipresCode, message, rawtext):
         self.httpStatus = httpStatus 
@@ -43,23 +48,34 @@ class ValidationError(CipresError):
 
 class Client(object):
     global verbose
-    def __init__(self, appname, appID, username, password, baseUrl):
-        """ baseUrl is something like https://host/cipresrest/v1 """
+    def __init__(self, appname, appID, username, password, baseUrl, endUserHeaders=None):
+        """ baseUrl is something like https://host/cipresrest/v1 
+            endUserHeaders are for applications that use umbrella authentication only.
+        """
         self.appname = appname
         self.appID = appID
         self.username = username
         self.password = password
         self.baseUrl = baseUrl
         self.headers = {'cipres-appkey': self.appID }
+        if endUserHeaders:
+            self.endUsername = endUserHeaders.get('cipres-eu')
+            if not self.endUsername or not endUserHeaders.get('cipres-eu-email'):
+                raise Exception("endUserHeaders must include cipres-eu and cipres-eu-email")
+            self.headers.update(endUserHeaders)
+            self.endUsername = self.appname + "." + self.endUsername
+        else:
+            self.endUsername = self.username
+
 
     def listJobs(self):
         """ returns list of JobStatus objects """
-        r = self.__doGet__(url=self.baseUrl + "/job/" + self.username + "/?expand=true")
+        r = self.__doGet__(url=self.baseUrl + "/job/" + self.endUsername + "/?expand=true")
         return self.__parseJobList__(r.text)
 
     def getJobStatus(self, jobHandle):
         """ queries for status and returns JobStatus object """
-        return JobStatus(client=self, jobUrl=self.baseUrl + "/job/" + self.username + "/" + jobHandle)
+        return JobStatus(client=self, jobUrl=self.baseUrl + "/job/" + self.endUsername + "/" + jobHandle)
 
     def submitJob(self, vParams, inputParams, metadata, validateOnly=False ):
         """ 
@@ -83,33 +99,33 @@ class Client(object):
         files = {}
         try:
             for key in inputParams:
-                paramname = "input.%s" % (key)
+                paramname = _prefixProperty(key, "input.")
                 pathname = inputParams[key]
                 files[paramname] = open(pathname, 'rb')
             payload = []
             if isinstance(vParams, dict):
                 for key in vParams:
-                    if key == "toolId":
+                    if key == "toolId" or key == "tool":
                         name = "tool"
                     else:
-                        name = "vparam.%s" % (key)
+                        name = _prefixProperty(key, "vparam.");
                     payload.append((name, vParams[key]))
             else:
                 for tuple in vParams:
-                    if tuple[0] == "toolId":
+                    if tuple[0] == "toolId" or tuple[0] == "tool":
                         name  = "tool"
                     else:
-                        name = "vparam.%s" % (tuple[0])
+                        name = _prefixProperty(tuple[0], "vparam.")
                     payload.append((name, tuple[1]))
             if metadata:
                 for key in metadata:
-                    name = "metadata.%s" % (key)
+                    name = _prefixProperty(key, "metadata.");
                     payload.append((name, metadata[key]))
 
             if validateOnly:
-                url = self.baseUrl + "/job/" + self.username + "/validate"
+                url = self.baseUrl + "/job/" + self.endUsername + "/validate"
             else:
-                url = self.baseUrl + "/job/" + self.username
+                url = self.baseUrl + "/job/" + self.endUsername
 
             response = requests.post(url, data=payload, files=files, auth=(self.username, self.password), headers=self.headers, verify=False)
             if verbose:
@@ -126,6 +142,7 @@ class Client(object):
         finally:
             for param, openfile in files.iteritems():
                 openfile.close
+                
 
     def validateJob(self, vParams, inputParams, metadata ):
         """ Validates a job and returns  a JobStatus object where commandline is the only field set. 
