@@ -80,6 +80,16 @@ def cipresjob(argv):
 
     properties = CipresClient.Application().getProperties()
     client = CipresClient.Client(properties.APPNAME, properties.APPID, properties.USERNAME, properties.PASSWORD, properties.URL)
+
+    """
+        Instead of creating the Client as above, UMBRELLA Applications would supply info about the end user in endUserHeaders, 
+        as in the example below.  You must instantiate a separate client for each end user (it is very lightweight; it's fine
+        to create a new client each time you make a request).
+
+        client = CipresClient.Client(properties.APPNAME, properties.APPID, properties.USERNAME, properties.PASSWORD, properties.URL,
+            endUserHeaders = {'cipres-eu' : 'terri100', 'cipres-eu-email' : 'terri100@yahoooo.com'} ) 
+    """
+
     if properties.VERBOSE:
         print "Setting CipresClient.verbose"
         CipresClient.verbose = True
@@ -133,7 +143,7 @@ def cipresjob(argv):
 # Call this with the complete sys.argv array
 def tooltest(argv):
     """
-        tooltest.py TEMPLATE_DIRECTORY validate|run [results_directory]
+        tooltest.py TEMPLATE_DIRECTORY validate|run [results_directory] 
         
         Where TEMPLATE_DIRECTORY is the name of a directory that contains the job's input data files and
         two property files named testInput.properties and testParam.properties.
@@ -152,7 +162,6 @@ def tooltest(argv):
             doesn't exist, tooltest.py will create it. Intermediate directories, however, will not be created.
             If results_directory isn't specified, the default is directory name is ./jobhandle where jobhandle 
             is the CIPRES assigned job handle, a long guid, starting with "NGBW-".
-        
     """
 
     if not argv or len(argv) < 3:
@@ -174,6 +183,17 @@ def tooltest(argv):
 
     properties = CipresClient.Application().getProperties()
     client = CipresClient.Client(properties.APPNAME, properties.APPID, properties.USERNAME, properties.PASSWORD, properties.URL)
+
+    """
+        Instead of creating the Client as above, UMBRELLA Applications would supply info about the end user in endUserHeaders, like this.  
+        You must instantiate a separate client for each end user (it is very lightweight; it's fine to create a new client for each 
+        request).
+
+        client = CipresClient.Client(properties.APPNAME, properties.APPID, properties.USERNAME, properties.PASSWORD, properties.URL,
+            endUserHeaders = {'cipres-eu' : 'terri100', 'cipres-eu-email' : 'terri100@yahoooo.com'} ) 
+    """
+
+
     if properties.VERBOSE:
         CipresClient.verbose = True
     try:
